@@ -32,7 +32,7 @@
 using namespace KIdentityManagement;
 
 // TODO: should use a kstaticdeleter?
-static Identity *identityNull = Q_NULLPTR;
+static Identity *identityNull = nullptr;
 
 Q_DECLARE_METATYPE(KIdentityManagement::Signature)
 
@@ -688,7 +688,8 @@ bool Identity::matchesEmailAddress(const QString &addr) const
         return true;
     }
 
-    foreach (const QString &alias, emailAliases()) {
+    const QStringList lst = emailAliases();
+    for (const QString &alias : lst) {
         if (alias.toLower() == addrSpec) {
             return true;
         }
